@@ -1,6 +1,6 @@
 package Statocles::Command;
 # ABSTRACT: The statocles command-line interface
-$Statocles::Command::VERSION = '0.026';
+$Statocles::Command::VERSION = '0.027';
 use Statocles::Class;
 use Getopt::Long qw( GetOptionsFromArray );
 use Pod::Usage::Return qw( pod2usage );
@@ -96,7 +96,8 @@ sub main {
                 my $dest = $theme_dest->child( $relative );
                 # Don't overwrite site-customized hooks
                 next if ( $path->stat->size == 0 && $dest->exists );
-                $dest->touchpath;
+                $dest->remove if $dest->exists;
+                $dest->parent->mkpath;
                 $path->copy( $dest );
             }
             say qq{Theme "$theme_name" written to "share/theme/$theme_name"};
@@ -196,7 +197,7 @@ Statocles::Command - The statocles command-line interface
 
 =head1 VERSION
 
-version 0.026
+version 0.027
 
 =head1 SYNOPSIS
 
