@@ -1,6 +1,6 @@
 package Statocles::Site::Git;
 # ABSTRACT: A git-based site
-$Statocles::Site::Git::VERSION = '0.026';
+$Statocles::Site::Git::VERSION = '0.027';
 use Statocles::Class;
 extends 'Statocles::Site';
 
@@ -62,13 +62,15 @@ sub _git_run {
     my ( $git, @args ) = @_;
     my $cmdline = join " ", 'git', @args;
     my $cmd = $git->command( @args );
-    my $stdout = readline( $cmd->stdout ) // '';
-    my $stderr = readline( $cmd->stderr ) // '';
+    my $stdout = join( "\n", readline( $cmd->stdout ) ) // '';
+    my $stderr = join( "\n", readline( $cmd->stderr ) ) // '';
     $cmd->close;
     my $exit = $cmd->exit;
+
     if ( $exit ) {
-        warn "git $args[0] exited with $exit\n-- CMD --\n$cmdline\n-- STDOUT --\n$stdout\n-- STDERR --\n$stderr\n";
+        die "git $args[0] exited with $exit\n\n-- CMD --\n$cmdline\n\n-- STDOUT --\n$stdout\n\n-- STDERR --\n$stderr\n";
     }
+
     return $cmd->exit;
 }
 
@@ -100,7 +102,7 @@ Statocles::Site::Git - A git-based site
 
 =head1 VERSION
 
-version 0.026
+version 0.027
 
 =head1 DESCRIPTION
 
